autoConnect property
If true, skips the configuration screen and goes directly to the browser Requires serverUrl and shareToken to be provided
Implementation
final bool autoConnect;
If true, skips the configuration screen and goes directly to the browser Requires serverUrl and shareToken to be provided
final bool autoConnect;