browserAppBar property
Optional custom AppBar widget for the browser screen If provided, this will override the default AppBar with title
Implementation
final PreferredSizeWidget? browserAppBar;
Optional custom AppBar widget for the browser screen If provided, this will override the default AppBar with title
final PreferredSizeWidget? browserAppBar;