configurationAppBar property
Optional custom AppBar widget for the configuration screen If provided, this will override the default AppBar with title
Implementation
final PreferredSizeWidget? configurationAppBar;
Optional custom AppBar widget for the configuration screen If provided, this will override the default AppBar with title
final PreferredSizeWidget? configurationAppBar;