serverUrl property
Optional pre-configured server URL If provided, the configuration screen will be pre-filled
Implementation
final String? serverUrl;
Optional pre-configured server URL If provided, the configuration screen will be pre-filled
final String? serverUrl;