NextcloudConfig class

Constructors

NextcloudConfig({required String baseUrl, required String username, required String password})
NextcloudConfig.authenticated({required String serverUrl, required String username, required String password})
factory
NextcloudConfig.publicShare({required String serverUrl, required String shareToken, String password = ''})
factory

Properties

baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
password String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited