NextcloudService class

Constructors

NextcloudService(NextcloudConfig config)

Properties

baseUrl String
no setter
config NextcloudConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect() Future<void>
Verifies the connection to the Nextcloud server using the provided configuration. Throws an exception if the connection fails or credentials are invalid.
createFolder(String folderPath) Future<void>
deleteItem(String itemPath) Future<void>
downloadFile(NextcloudItem item, String savePath) Future<void>
listDirectory(String path) Future<List<NextcloudItem>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renameItem(String oldPath, String newPath) Future<void>
toString() String
A string representation of this object.
inherited
uploadFile(String localFilePath, String remotePath, {dynamic onProgress(int sent, int total)?}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited