flutter_nextcloud library
A Flutter package for browsing, downloading, and managing files from Nextcloud servers.
This package provides a complete solution for interacting with Nextcloud servers using the WebDAV protocol. It supports both public shares and authenticated user accounts.
Classes
- ConfigurationScreen
- FlutterNextcloud
- Main widget for Flutter Nextcloud package.
- NextcloudBrowserScreen
- NextcloudConfig
- NextcloudItem
- NextcloudService
Functions
-
base64Encode(
List< int> bytes) → String